@@ -145,6 +145,8 @@ private slots:
     void loadFromModuleFailures();
     void loadFromModuleRequired();
     void loadFromQrc();
+    void removeBinding();
+    void complexObjectArgument();
 
 private:
     QQmlEngine engine;
@@ -1245,12 +1247,14 @@ void tst_qqmlcomponent::boundComponent()
     {
         QQmlComponent component(&engine, testFileUrl("nestedBoundComponent.qml"));
         QVERIFY2(component.isReady(), qPrintable(component.errorString()));
+        QVERIFY(component.isBound());
 
         QScopedPointer<QObject> o(component.create());
         QVERIFY(!o.isNull());
 
         QQmlComponent *nestedComponent = o->property("c").value<QQmlComponent *>();
         QVERIFY(nestedComponent != nullptr);
+        QVERIFY(nestedComponent->isBound());
 
         QObject *nestedObject = o->property("o").value<QObject *>();
         QVERIFY(nestedObject != nullptr);
@@ -1269,6 +1273,7 @@ void tst_qqmlcomponent::boundComponent()
     {
         QQmlComponent component(&engine, testFileUrl("BoundInlineComponent.qml"));
         QVERIFY2(component.isReady(), qPrintable(component.errorString()));
+        QVERIFY(component.isBound());
 
         QScopedPointer<QObject> o(component.create());
         QVERIFY2(!o.isNull(), qPrintable(component.errorString()));
@@ -1282,11 +1287,22 @@ void tst_qqmlcomponent::boundComponent()
     {
         QQmlComponent component(&engine, testFileUrl("boundInlineComponentUser.qml"));
         QVERIFY2(component.isReady(), qPrintable(component.errorString()));
+        QVERIFY(!component.isBound());
         QScopedPointer<QObject> o(component.create());
         QVERIFY(o.isNull());
 
         QVERIFY(component.errorString().contains(
                 QLatin1String("Cannot instantiate bound inline component in different file")));
+
+    }
+
+    {
+        QQmlComponent component(&engine);
+        QVERIFY(!component.isBound());
+
+        component.setData("pragma ComponentBehavior: Bound\nsyntax error", QUrl());
+        QCOMPARE(component.errorString(), ":2 Syntax error\n"_L1);
+        QVERIFY(!component.isBound());
     }
 }
 
@@ -1425,6 +1441,36 @@ void tst_qqmlcomponent::loadFromQrc()
     QVERIFY(p->compilationUnit->aotCompiledFunctions);
 }
 
+void tst_qqmlcomponent::removeBinding()
+{
+    QQmlEngine e;
+    const QUrl url = testFileUrl("removeBinding.qml");
+    QQmlComponent c(&e, url);
+    QVERIFY2(c.isReady(), qPrintable(c.errorString()));
+
+    QTest::ignoreMessage(
+        QtWarningMsg,
+        qPrintable(url.toString() + QStringLiteral(":7:27: QML Component: Unsuitable arguments "
+                                                   "passed to createObject(). The first argument "
+                                                   "should be a QObject* or null, and the second "
+                                                   "argument should be a JavaScript object or a "
+                                                   "QVariantMap")));
+    QScopedPointer<QObject> o(c.create());
+    QVERIFY(!o.isNull());
+    QCOMPARE(o->property("result"), QStringLiteral("42"));
+    QCOMPARE(o->property("result2"), QStringLiteral("43"));
+}
+
+void tst_qqmlcomponent::complexObjectArgument()
+{
+    QQmlEngine e;
+    QQmlComponent c(&e, testFileUrl("complexObjectArgument.qml"));
+    QVERIFY2(c.isReady(), qPrintable(c.errorString()));
+    QScopedPointer<QObject> o(c.create());
+    QVERIFY(!o.isNull());
+    QCOMPARE(o->objectName(), QStringLiteral("26"));
+}
+
 QTEST_MAIN(tst_qqmlcomponent)
 
 #include "tst_qqmlcomponent.moc"
